aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/app/state/state.go
diff options
context:
space:
mode:
authorOphestra <cat@gensokyo.uk>2025-09-29 02:33:10 +0900
committerOphestra <cat@gensokyo.uk>2025-09-29 06:11:47 +0900
commit46cd3a28c83e93b5d66c52d06a8366c11910d5c0 (patch)
tree6e25c5078b5cd9de78b7a6c9b253f1132358812b /internal/app/state/state.go
parentad1bc6794f0053c3e63eab408a0d530d53e8b51c (diff)
container: remove global msg
This frees all container instances of side effects. Signed-off-by: Ophestra <cat@gensokyo.uk>
Diffstat (limited to 'internal/app/state/state.go')
-rw-r--r--internal/app/state/state.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/internal/app/state/state.go b/internal/app/state/state.go
index 6a3a82db..59fbc8c7 100644
--- a/internal/app/state/state.go
+++ b/internal/app/state/state.go
@@ -19,9 +19,9 @@ type Store interface {
// Cursor provided to f becomes invalid as soon as f returns.
Do(identity int, f func(c Cursor)) (ok bool, err error)
- // List queries the store and returns a list of aids known to the store.
- // Note that some or all returned aids might not have any active apps.
- List() (aids []int, err error)
+ // List queries the store and returns a list of identities known to the store.
+ // Note that some or all returned identities might not have any active apps.
+ List() (identities []int, err error)
// Close releases any resources held by Store.
Close() error